@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-
+from __future__ import print_function
 import stretch_body.arm as arm
 import stretch_body.hello_utils as hu
 hu.print_stretch_re_use()
@@ -10,7 +10,8 @@ parser.add_argument("--double", help="Home to both hardstops",action="store_true
 args=parser.parse_args()
 
 a=arm.Arm()
-a.startup()
+if not a.startup():
+    exit()
 a.home(single_stop= not args.double)
 a.stop()
 
